==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Programma Voorkeursinstellingen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Tekenings Voorkeursinstellingen</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translation>Herstart nodig</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>Herstart QCAD om
de wijzigingen door te voeren.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Referentiepunt</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Bewerken gereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Bewerken gereedschappen tonen</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translation>Zoekopdracht terugzetten</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translation>Navigatiestructuur ontvouwen</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Navigatiestructuur invouwen</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Herstellen naar de standaardwaarden</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Programma Voorkeursinstellingen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Tekenings Voorkeursinstellingen</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation>Voorkeursinstellingen toepassen</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translation>Herstart nodig</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>Herstart QCAD om
de wijzigingen door te voeren.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Standaardinstellingen voor</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>Dit zijn standaard voorkeuren voor nieuwe tekeningen.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Voorkeuren van de huidige tekening kunnen worden gewijzigd onder&lt;br/&gt;&lt;i&gt;Bewerken &amp;gt; Tekening voorkeursinstellingen&lt;/i&gt;.</translation>
    </message>
    <message>
        <source>You are changing default preferences for new drawings.</source>
        <translation type="vanished">U bent het wijzigen van standaard voorkeuren voor nieuwe tekeningen.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Wijzigingen beïnvloeden nieuwe tekeningen, maar NIET de huidige tekening.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Referentiepunt</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Bewerken gereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Bewerken gereedschappen tonen</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerken</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translation type="vanished">Zoekopdracht terugzetten</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translation>Navigatiestructuur ontvouwen</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Navigatiestructuur invouwen</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Herstellen naar de standaardwaarden</translation>
    </message>
</context>
</TS>
